@@ -12,7 +12,7 @@
 #' For three-mode networks, `network_congruency` calculates the proportion of three-paths 
 #' spanning two two-mode networks that are closed by a fourth tie to establish a 
 #' "congruent four-cycle" structure.
-#' @param object A one-mode or two-mode matrix, igraph, or tidygraph
+#' @inheritParams is
 #' @param object2 Optionally, a second (two-mode) matrix, igraph, or tidygraph
 #' @param method For reciprocity, either `default` or `ratio`.
 #' See `?igraph::reciprocity`
@@ -35,19 +35,19 @@ NULL
 #' @examples
 #' network_reciprocity(ison_southern_women)
 #' @export
-network_reciprocity <- function(object, method = "default") {
-  make_network_measure(igraph::reciprocity(as_igraph(object), mode = method), 
-                     object)
+network_reciprocity <- function(.data, method = "default") {
+  make_network_measure(igraph::reciprocity(manynet::as_igraph(.data), mode = method), 
+                       .data)
 }
 
 #' @describeIn closure Calculate nodes' reciprocity
 #' @examples
 #' node_reciprocity(to_unweighted(ison_networkers))
 #' @export
-node_reciprocity <- function(object) {
-  out <- as_matrix(object)
+node_reciprocity <- function(.data) {
+  out <- manynet::as_matrix(.data)
   make_node_measure(rowSums(out * t(out))/rowSums(out), 
-                    object)
+                    .data)
 }
 
 #' @describeIn closure Calculate transitivity in a network
@@ -55,19 +55,19 @@ node_reciprocity <- function(object) {
 #' @examples
 #' network_transitivity(ison_adolescents)
 #' @export
-network_transitivity <- function(object) {
-  make_network_measure(igraph::transitivity(as_igraph(object)), 
-                     object)
+network_transitivity <- function(.data) {
+  make_network_measure(igraph::transitivity(manynet::as_igraph(.data)), 
+                       .data)
 }
 
 #' @describeIn closure Calculate nodes' transitivity
 #' @examples
 #' node_transitivity(ison_adolescents)
 #' @export
-node_transitivity <- function(object) {
-  make_node_measure(igraph::transitivity(as_igraph(object), 
+node_transitivity <- function(.data) {
+  make_node_measure(igraph::transitivity(manynet::as_igraph(.data), 
                                          type = "local"), 
-                       object)
+                    .data)
 }
 
 #' @describeIn closure Calculate equivalence or reinforcement 
@@ -75,9 +75,9 @@ node_transitivity <- function(object) {
 #' @examples
 #' network_equivalency(ison_southern_women)
 #' @export
-network_equivalency <- function(object) {
-  if (is_twomode(object)) {
-    mat <- as_matrix(object)
+network_equivalency <- function(.data) {
+  if (manynet::is_twomode(.data)) {
+    mat <- manynet::as_matrix(.data)
     c <- ncol(mat)
     indegrees <- colSums(mat)
     twopaths <- crossprod(mat)
@@ -88,16 +88,21 @@ network_equivalency <- function(object) {
              (matrix(indegrees, c, c) - twopaths)))
     if (is.nan(output)) output <- 1
   } else stop("This function expects a two-mode network")
-  make_network_measure(output, object)
+  make_network_measure(output, .data)
 }
 
 #' @describeIn closure Calculate congruency across two two-mode networks
 #' @export
-network_congruency <- function(object, object2){
-  if(missing(object) | missing(object2)) stop("This function expects two two-mode networks")
-  mat1 <- as_matrix(object)
-  mat2 <- as_matrix(object2)
-  c <- ncol(mat1)
+network_congruency <- function(.data, object2){
+  if(missing(.data) | missing(object2)) stop("This function expects two two-mode networks")
+  if(!manynet::is_twomode(.data) | !manynet::is_twomode(object2)) stop("This function expects two two-mode networks")
+  if(manynet::network_dims(.data)[2] != manynet::network_dims(object2)[1]) 
+    stop(paste("This function expects the number of nodes",
+    "in the second mode of the first network", "to be the same as the number of nodes",
+    "in the first mode of the second network."))
+  mat1 <- manynet::as_matrix(.data)
+  mat2 <- manynet::as_matrix(object2)
+  connects <- ncol(mat1)
   twopaths1 <- crossprod(mat1)
   indegrees <- diag(twopaths1)
   diag(twopaths1) <- 0
@@ -109,8 +114,7 @@ network_congruency <- function(object, object2){
   output <- sum(twopaths * (twopaths - 1)) /
     (sum(twopaths * (twopaths - 1)) +
        sum(twopaths *
-             (matrix(degrees, c, c) - twopaths)))
+             (matrix(degrees, connects, connects) - twopaths)))
   if (is.nan(output)) output <- 1
-  make_network_measure(output, object)
+  make_network_measure(output, .data)
 }
-
